import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.Rectangle;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.BorderFactory;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.border.EtchedBorder;

import java.util.Enumeration;
import java.util.Vector;

public class PriorityStatusForm implements ActionListener 
{
	private JFrame jfFrame;
	
	private JLabel jlStatus;
	
	private JScrollPane jspPriorityTb;
	
	private JTable jtPriorityTb;
	
	private Vector vColHdr;
	private Vector vPriorityEntries;
	
	private JButton jbConfig;

	private PriorityDriverParameters pdpValues;
	
	private PriorityStatus psStatus;

	private ConfigForm cfConfig;
	
	public PriorityStatusForm(PriorityDriverParameters pdpValues, PriorityStatus psStatus)
	{
		this.pdpValues = pdpValues;
		this.psStatus = psStatus;
		init();
		loadForm();
		showForm();
	}
	
	public void updateForm(boolean bFileNotFound)
	{
		if(bFileNotFound)
		{
			this.setStatusMsg("Wireless Card Disabled!", new ImageIcon("inactiveAP.gif"));
			this.setPriorityEntries(new Vector());
			this.jbConfig.setEnabled(false);
		}
		else
		{
			this.setStatusMsg("Access Point is working!!!", new ImageIcon("activeAP.gif"));
			this.setPriorityEntries(this.pdpValues.getAllPriorityMAC());
			this.jbConfig.setEnabled(true);
		}	
	}
	
	private void init()
	{
		
		this.jfFrame = new JFrame("Priority IEEE802.11");
		this.jfFrame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		  //Sets the operation that will happen by default when the user initiates a "close" on this frame
		this.jfFrame.getContentPane().setLayout(new BorderLayout(5, 5));
		  //getContentPane --> the "Container" (=the simplest container is a "panel") of the jfFrame
		  //setLayout --> Sets the "layout manager" (=an object that designs the container) for this container
		
		this.jlStatus = new JLabel("Is Access Point working?", new ImageIcon("questionAP.gif"), JLabel.LEFT); 
		
		this.vColHdr = new Vector();
		this.vColHdr.add("MAC");
		this.vColHdr.add("Owner");
		
		this.vPriorityEntries = new Vector();
		Vector vNullEntry = new Vector(); vNullEntry.add(""); vNullEntry.add(""); 
		for(int i=0; i<20; i++) this.vPriorityEntries.add(vNullEntry);
	
		this.jtPriorityTb = new JTable(this.vPriorityEntries, this.vColHdr);
		this.jtPriorityTb.setAutoResizeMode(JTable.AUTO_RESIZE_ALL_COLUMNS);
		this.jspPriorityTb = new JScrollPane(this.jtPriorityTb, JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED, JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED );
		this.jspPriorityTb.setBorder(BorderFactory.createTitledBorder(BorderFactory.createEtchedBorder(EtchedBorder.RAISED), "MACs with Priority"));
		  //setBorder --> sets the line arround of the component
		
		this.jbConfig = new JButton("Configure >>");
		this.jbConfig.addActionListener(this);
	}
	
	private void loadForm()
	{
		
		GridBagLayout gblLayout = new GridBagLayout();
		GridBagConstraints gbcConst = new GridBagConstraints();
		gbcConst.fill = GridBagConstraints.BOTH; //resizes the gblLayout if its display area is bigger than the required.
		gbcConst.weightx = 1.0;
		gbcConst.insets = new Insets(5, 5, 5, 5);
		gbcConst.gridwidth = GridBagConstraints.REMAINDER;

		JPanel jpStatus = new JPanel();
		jpStatus.setBorder(BorderFactory.createTitledBorder(BorderFactory.createEtchedBorder(EtchedBorder.RAISED), "Status"));
		jpStatus.setLayout(new BorderLayout());
		jpStatus.add(this.jlStatus, BorderLayout.CENTER);

		JPanel jpWholePanel = new JPanel();
		jpWholePanel.setLayout(gblLayout);

		gblLayout.setConstraints(jpStatus, gbcConst);
		jpWholePanel.add(jpStatus);
		
		gbcConst.weighty = 1.0;
		gblLayout.setConstraints(this.jspPriorityTb, gbcConst);
		jpWholePanel.add(this.jspPriorityTb);

		gbcConst.gridheight = 1;
		gbcConst.weighty = 0;
		gbcConst.fill = GridBagConstraints.NONE;
		gbcConst.anchor = GridBagConstraints.SOUTHEAST;
		gblLayout.setConstraints(this.jbConfig, gbcConst);
		this.jfFrame.getContentPane().add(jpWholePanel, BorderLayout.CENTER);
		
		JPanel jpButtonConfigure = new JPanel(new BorderLayout());
		jpButtonConfigure.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
		jpButtonConfigure.add(this.jbConfig,BorderLayout.EAST);
		this.jfFrame.getContentPane().add(jpButtonConfigure, BorderLayout.SOUTH);
	}
	
	private void showForm()
	{
		this.jfFrame.setSize(new Dimension(400, 450));
		this.jfFrame.pack();
		Rectangle bounds = this.jfFrame.getGraphicsConfiguration().getBounds();
		this.jfFrame.setLocation(bounds.width/2 - this.jfFrame.getWidth()/2, bounds.height/2 - this.jfFrame.getHeight()/2);
		this.jfFrame.setVisible(true);
	}
	
/*	public static void main(String[] args)
	{
		new PriorityStatusForm(new PriorityDriverParameters());
	}
*/
	public void actionPerformed(ActionEvent arg0) 
	{
		if(arg0.getSource() == this.jbConfig)
		{
			this.cfConfig = new ConfigForm(this.jfFrame, this.pdpValues, this.psStatus, this);
		}
	}
	
	public void setStatusMsg(String sMsg, ImageIcon icStatusAP)
	{
		this.jlStatus.setText(sMsg);
		this.jlStatus.setIcon(icStatusAP);
	}
		
	public void setPriorityEntries(Vector vPriorityNewEntries)
	{
		int countNull = this.vPriorityEntries.size();

		this.vPriorityEntries.removeAllElements();

		Enumeration enumVar = vPriorityNewEntries.elements();
		while(enumVar.hasMoreElements())
		{
			this.vPriorityEntries.add(((Vector)enumVar.nextElement()).clone());
		}

		countNull -= this.vPriorityEntries.size();

		Vector vNullEntry = new Vector(); vNullEntry.add(""); vNullEntry.add(""); 
		for(int i=0; i<countNull; i++) this.vPriorityEntries.add(vNullEntry);

		this.jtPriorityTb.revalidate();
		this.jspPriorityTb.repaint();
		this.jspPriorityTb.revalidate();
	}
	
}
